@@ -1,5 +1,6 @@
 from __future__ import division
 
+import math
 import os.path as osp
 from pathlib import Path
 import shutil
@@ -103,3 +104,48 @@ def extract_target_frame_from_timestamp(video_filepath, timestamp):
     vidcap.set(cv2.CAP_PROP_POS_MSEC, int(timestamp * 1000))
     success, image = vidcap.read()
     return image
+
+
+def load_frame(video_path, start=0.0, duration=-1,
+               target_size=None, sampling_frequency=None):
+    """Load frame
+
+    Parameters
+    ----------
+    video_path : str or pathlib.Path
+        input video path.
+    start : float
+        start time
+    duration : int or float
+        duration. If this value is `-1`, load all frames.
+
+    Returns
+    -------
+    frames : list[numpy.ndarray]
+        all frames.
+    stamps : list[float]
+        time stamps.
+    """
+    video_path = str(video_path)
+    vid = cv2.VideoCapture(video_path)
+    fps = vid.get(cv2.CAP_PROP_FPS)
+    vid.set(cv2.CAP_PROP_POS_MSEC, start)
+    vid_avail = True
+    if sampling_frequency is not None:
+        frame_interval = int(math.ceil(fps * sampling_frequency))
+    else:
+        frame_interval = 1
+    cur_frame = 0
+    while True:
+        stamp = float(cur_frame) / fps
+        vid_avail, frame = vid.read()
+        if not vid_avail:
+            break
+        if duration != -1 and stamp > start + duration:
+            break
+        if target_size is not None:
+            frame = cv2.resize(frame, target_size)
+        yield frame, stamp
+        cur_frame += frame_interval
+        vid.set(cv2.CAP_PROP_POS_FRAMES, cur_frame)
+    vid.release()
